searchData={"items":[{"type":"module","title":"Pockets","doc":"`Pockets` is a wrapper around Erlang [`:ets`](https://erlang.org/doc/man/ets.html)\nand [`:dets`](https://erlang.org/doc/man/dets.html), built-in options for memory- and disk-based term storage.\nIt offers simple key/value storage using an interface similar to the `Map` or `Keyword` modules. This can be a useful\npersistent cache for many use cases.\n\nNote that this package and the libraries that underpin it may have limitations or specific behaviors that may affect\nits suitability for various use-cases.  For example, the limited support for concurrency provided by the `:ets(3)`\nmodule is not yet provided by `:dets`.\n\nSee also\n\n- [stash](https://github.com/whitfin/stash)\n- [\"What is ETS in Elixir?\"](https://culttt.com/2016/10/05/what-is-ets-in-elixir/)","ref":"Pockets.html"},{"type":"type","title":"Pockets.alias/0","doc":"A table alias is used to refer to a `Pockets` table: it is usually an atom, but in some cases\nit may be a reference (e.g. in an `:ets` table with `named_table: false`).","ref":"Pockets.html#t:alias/0"},{"type":"function","title":"Pockets.close/1","doc":"Closes the given table (i.e. the opposite of `open/3`).\nOnly processes that have opened a table are allowed to close it.\nFor `:ets` in-memory tables, this is the same as `destroy/1`.\nFor `:dets` disk-based tables, this will save any outstanding changes to the file.","ref":"Pockets.html#close/1"},{"type":"function","title":"Pockets.delete/2","doc":"Deletes the entry in table for a specific `key`. Because this returns the table alias, you can\npipe multiple operations together.","ref":"Pockets.html#delete/2"},{"type":"function","title":"Examples - Pockets.delete/2","doc":"iex> Pockets.new(:my_cache)\n    {:ok, :my_cache}\n    iex> Pockets.merge(:my_cache, %{a: \"apple\", b: \"boy\", c: \"cat\"})\n    :my_cache\n    iex> Pockets.to_map(:my_cache)\n    %{a: \"apple\", b: \"boy\", c: \"cat\"}\n    iex> Pockets.delete(:my_cache, :b)\n    :my_cache\n    iex> Pockets.to_map(:my_cache)\n    %{a: \"apple\", c: \"cat\"}","ref":"Pockets.html#delete/2-examples"},{"type":"function","title":"Pockets.destroy/1","doc":"Destroys the given table.\nFor disk-based (`:dets`) tables, this will delete the backing file.\nFor memory-based (`:ets`) tables, this destroys the table and its contents.","ref":"Pockets.html#destroy/1"},{"type":"function","title":"Examples - Pockets.destroy/1","doc":"iex> Pockets.new(:my_cache, \"/tmp/cache.dets\")\n    {:ok, :my_cache}\n    iex> Pockets.destroy(:my_cache)\n    :ok","ref":"Pockets.html#destroy/1-examples"},{"type":"function","title":"Pockets.empty?/1","doc":"Checks if the given table is empty.\nThis will return `true` if the given table does not exist.","ref":"Pockets.html#empty?/1"},{"type":"function","title":"Examples - Pockets.empty?/1","doc":"iex> {:ok, tid} = Pockets.new(:my_cache)\n    {:ok, :my_cache}\n    iex> Pockets.empty?(tid)\n    true","ref":"Pockets.html#empty?/1-examples"},{"type":"function","title":"Pockets.exists?/1","doc":"Checks if the table exists in the `Pockets` registry.\n\nNote: this function does _not_ check whether an ETS or DETS table was\ncreated outside of `Pockets` (e.g. via ETS or DETS directly).\nFor those cases, see [`:ets.whereis/1`](https://erlang.org/doc/man/ets.html#whereis-1)\nor [`:dets.info/1`](https://erlang.org/doc/man/dets.html#info-1).","ref":"Pockets.html#exists?/1"},{"type":"function","title":"Pockets.filter/2","doc":"Akin to `Enum.filter/2`, this function will pare down the contents of the given\ntable preserving only entries for which `fun` returns a truthy value.\nSimilar to using `Enum.filter/2` on maps, the `fun` receives a tuple representing\nthe key and the value stored at that location.\n\nThe result of a successful operation is an `:ok` tuple including the count of\nrows removed.\n\n\n>","ref":"Pockets.html#filter/2"},{"type":"function","title":"This Updates the Table In Place! {: .warning} - Pockets.filter/2","doc":">\n> This operation updates the table in place, so it has the potential to delete\n> every item in the table. Use it carefully!\n>\n> If a safer alternative is needed, use `Pockets.to_stream/1` to manipulate values\n> and feed the results into a new table.","ref":"Pockets.html#filter/2-this-updates-the-table-in-place-warning"},{"type":"function","title":"Examples - Pockets.filter/2","doc":"iex> Pockets.new(:ex)\n    iex> Pockets.merge(:ex, %{a: 12, b: 7, c: 22, d: 8})\n    iex> Pockets.filter(:ex, fn {_, v} -> v > 10 end)\n    {:ok, 2}\n    iex> Pockets.to_map(:ex)\n    %{a: 12, c: 22}","ref":"Pockets.html#filter/2-examples"},{"type":"function","title":"See Also - Pockets.filter/2","doc":"- `reject/2`","ref":"Pockets.html#filter/2-see-also"},{"type":"function","title":"Pockets.get/3","doc":"Gets the value for a specific `key` in the table.\n\nFor tables of type `:set`, this function behaves like `Map.get/3`: the value is returned (if present),\notherwise the `default` is returned.\n\nHowever, for tables of type `:bag` and `:duplicate_bag`, this function will _always_ return a list and the\n`default` is ignored.  This has to do with keyword lists being the underlying data structure powering all\nof this.\n\nThe default value will be returned if the table does not exist.","ref":"Pockets.html#get/3"},{"type":"function","title":"Examples - Pockets.get/3","doc":"iex> Pockets.new(:t1, :memory, type: :set)\n    {:ok, :t1}\n    iex> Pockets.get(:t1, :x, \"Default Value\")\n    \"Default Value\"\n\n    iex> Pockets.new(:t2, :memory, type: :bag)\n    {:ok, :t2}\n    iex> Pockets.get(:t2, :x, \"Ignored Default Value\")\n    []\n\n    # Bag\n    iex> Pockets.new(:t_bag, :memory, type: :bag)\n    {:ok, :t_bag}\n    iex> Pockets.put(:t_bag, :c, \"Cream\")\n    :t_bag\n    iex> Pockets.put(:t_bag, :c, \"Sugar\")\n    :t_bag\n    iex> Pockets.put(:t_bag, :c, \"Sugar\")\n    :t_bag\n    iex> Pockets.get(:t_bag, :c)\n    [\"Cream\", \"Sugar\"]\n\n    # Duplicate Bag\n    iex> Pockets.new(:t_dupe_bag, :memory, type: :duplicate_bag)\n    {:ok, :t_dupe_bag}\n    iex> Pockets.put(:t_dupe_bag, :c, \"Cream\")\n    :t_bag\n    iex> Pockets.put(:t_dupe_bag, :c, \"Sugar\")\n    :t_bag\n    iex> Pockets.put(:t_dupe_bag, :c, \"Sugar\")\n    :t_bag\n    iex> Pockets.get(:t_bag, :c)\n    [\"Cream\", \"Sugar\", \"Sugar\"]","ref":"Pockets.html#get/3-examples"},{"type":"function","title":"Pockets.has_key?/2","doc":"Checks if the table has the given `key`.\n\n`false` is returned if the table does not exist.","ref":"Pockets.html#has_key?/2"},{"type":"function","title":"Pockets.incr/4","doc":"Increments the value at the given `key` by the given `step` (default 1).\nIf the table does not exist or the value at the given `key` is not a number,\nno action is taken.","ref":"Pockets.html#incr/4"},{"type":"function","title":"Examples - Pockets.incr/4","doc":"iex> Pockets.new(:inc_table)\n      :inc_table\n      |> Pockets.incr(:x)\n      |> Pockets.incr(:x)\n      |> Pockets.get(:x)\n    2\n\nDecrement a value:\n\n    iex> Pockets.new(:decr_table)\n      :decr_table\n      |> Pockets.incr(:x, -1, 10)\n      |> Pockets.incr(:x, -1)\n      |> Pockets.get(:x)\n    8","ref":"Pockets.html#incr/4-examples"},{"type":"function","title":"Pockets.info/1","doc":"Gets info about the given table.\nAn `:error` tuple is returned if the table does not exist.","ref":"Pockets.html#info/1"},{"type":"function","title":"Pockets.info/2","doc":"Gets info about the given `item` in the table. The available items depend on the type of table.\nAn error tuple is returned if the table does not exist.","ref":"Pockets.html#info/2"},{"type":"macro","title":"Pockets.is_alias/1","doc":"","ref":"Pockets.html#is_alias/1"},{"type":"function","title":"Pockets.keys/1","doc":"Gets a list of keys in the given table. For larger tables, consider `keys_stream/1`\nAn error tuple is returned if the table does not exist.","ref":"Pockets.html#keys/1"},{"type":"function","title":"Pockets.keys_stream/1","doc":"Gets a list of keys in the given table as a stream.\nAn error tuple is returned if the table does not exist.","ref":"Pockets.html#keys_stream/1"},{"type":"function","title":"Pockets.merge/2","doc":"This is a powerful function that lets you merge `input` into an open table.\nAll data in the input will be added to the table: the keys in the `input` \"have precedence\"\nover pre-existing keys in the table.\n\nWhen the `input` to be merged is...\n\n  - an alias for another table, the contents from that table are added to the given `table_alias`\n  - a map, the contents from the map are added into the given `table_alias`\n  - a list, the contents from the list are added into the given `table_alias`","ref":"Pockets.html#merge/2"},{"type":"function","title":"Examples - Pockets.merge/2","doc":"# Merging a map into a table:\n    iex> Pockets.new(:my_cache)\n    {:ok, :my_cache}\n    iex> Pockets.merge(:my_cache, %{a: \"apple\", b: \"boy\", c: \"cat\"})\n    :my_cache\n    iex> Pockets.to_map(:my_cache)\n    %{a: \"apple\", b: \"boy\", c: \"cat\"}\n\n    # Merging two tables:\n    iex> Pockets.new(:my_first)\n    {:ok, :my_first}\n    iex> Pockets.merge(:my_first, %{a: \"apple\", b: \"boy\", c: \"cat\"})\n    :my_first\n    iex> Pockets.new(:my_second)\n    {:ok, :my_second}\n    iex> Pockets.merge(:my_second, %{x: \"xray\", y: \"yellow\", z: \"zebra\"})\n    :my_second\n    iex> Pockets.merge(:my_first, :my_second)\n    :my_first\n    iex> Pockets.to_map(:my_first)\n    %{a: \"apple\", b: \"boy\", c: \"cat\", x: \"xray\", y: \"yellow\", z: \"zebra\"}","ref":"Pockets.html#merge/2-examples"},{"type":"function","title":"Pockets.new/3","doc":"Creates a new table either in memory (default) or on disk.\n\nThe second argument specifies the storage mechanism for the table, either a path to a file (as a string)\nfor disk-backed tables (`:dets`), or in `:memory` for memory-backed tables (`:ets`).\n\nThe available `opts` are specific to the storage engine being used.","ref":"Pockets.html#new/3"},{"type":"function","title":"In Memory - Pockets.new/3","doc":"When creating a new memory-based table (i.e. the second argument is `:memory` or is omitted),\nthe following options are supported:\n\n- `:type` One of `[:bag, :duplicate_bag, :set]` Default: `set`\n- `:access` One of `:public` | `:protected` | `:private`. Default: `:public`\n- `:named_table` boolean affects how the table is referenced.\n    If `false`, the table alias will be a reference (not an atom). Default: `true`\n- `:keypos` integer indicating the position of the element of each object to be used as key. Default: `1`\n- `:read_concurrency` boolean. Default: `true`\n- `:write_concurrency` boolean. Default: `true`\n- `:decentralized_counters` boolean. Default: `false`\n- `:compressed` boolean. Default: `false`\n\nThe full list of default options for memory-based tables are:\n```\n[type: :set, access: :public, named_table: true, keypos: 1, read_concurrency: true, write_concurrency: true, decentralized_counters: false, compressed: false]\n```\n\nThe structure of the options is changed from the [original](https://erlang.org/doc/man/ets.html)\nto make them more compatible with Elixir conventions. See the original documentation for specifics\nabout each option.","ref":"Pockets.html#new/3-in-memory"},{"type":"function","title":"File-based Tables - Pockets.new/3","doc":"When creating a new disk-based table (i.e. the second argument is a string path to a file),\nthe following options are supported:\n\n- `:type` One of `[:bag, :duplicate_bag, :set]` Default: `set`\n- `:access` One of `:read` | `:read_write`. Default: `:read_write`\n- `:auto_save` integer or `:infinity` specifying the autosave interval (where `:infinity` disables the feature). Default: `180000` (3 minutes)\n- `:keypos` integer indicating the position of the element of each object to be used as key. Default: `1`\n- `:file` The name of the file to be opened. Defaults to the table name. (Use of this confusing option is not recommended)\n- `:max_no_slots` The maximum number of slots to be used. Default: `32 M` (million?)\n- `:min_no_slots` Application performance can be enhanced with this flag by specifying the estimated number of\n    different keys to be stored in the table. Default: `256` (minimum)\n- `:ram_file` boolean. Whether the table is to be kept in RAM.\n    Keeping the table in RAM can sound like an anomaly, but can enhance the performance of applications that open\n    a table, insert a set of objects, and then close the table. When the table is closed, its contents are written\n    to the disk file. Default: `false`\n- `:repair` boolean or `:force`. The flag specifies if the `:dets` server invokes the automatic file reparation\n    algorithm. Default: `true`\n\nThe default options for disk-based tables are:\n```\n[type: :set]\n```","ref":"Pockets.html#new/3-file-based-tables"},{"type":"function","title":"Examples - Pockets.new/3","doc":"iex> Pockets.new(:ram_cache, :memory)\n    {:ok, :ram_cache}\n\n    iex> Pockets.new(:disk_cache, \"/tmp/my.dets\")\n    {:ok, :disk_cache}","ref":"Pockets.html#new/3-examples"},{"type":"function","title":"Pockets.open/3","doc":"Open a table for use. The behavior and available options of this function vary\ndepending on the storage mechanism of the table (i.e.memory or disk).","ref":"Pockets.html#open/3"},{"type":"function","title":"Memory-based Tables - Pockets.open/3","doc":"For memory-based tables `open/3` is synonymous with `new/3`.","ref":"Pockets.html#open/3-memory-based-tables"},{"type":"function","title":"Disk-based Tables - Pockets.open/3","doc":"Because a file is involved, the `:create?` option provides a bit more control over how to handle cases when the\nfile does not exist.\n\nOptions\n\n- `:create?` Indicates whether a new table should be created if the one being requested does not already exist. Default: `false`\n\nIf `:create?` is `true` and the filepath indicated by the second argument does not exist,\n`open/3` is synonymous with `new/3`.","ref":"Pockets.html#open/3-disk-based-tables"},{"type":"function","title":"Examples - Pockets.open/3","doc":"iex> Pockets.open(:my_cache)\n    {:ok, :my_cache}\n    iex> Pockets.open(:my_cache, :memory)\n    {:ok, :my_cache}\n    iex> Pockets.open(:disk_cache, \"/tmp/cache.dets\")\n    {:ok, :disk_cache}\n    iex> Pockets.open(:boo, \"/tmp/does_not_exist_yet.dets\", create?: true)\n    {:ok, :boo}","ref":"Pockets.html#open/3-examples"},{"type":"function","title":"Pockets.put/3","doc":"Puts the given `value` under `key` in given table.\n\nFor tables of type `:set`, this will behave like `Map.put/3`.\n\nOther table types aren't as straightforward. See the examples under `get/3`","ref":"Pockets.html#put/3"},{"type":"function","title":"Examples - Pockets.put/3","doc":"# Set\n    iex> Pockets.new(:t_set)\n    {:ok, :t_set}\n    iex> Pockets.put(:t_set, :z, \"Zulu\")\n    :t_set\n    iex> Pockets.get(:t_set, :z)\n    \"Zulu\"","ref":"Pockets.html#put/3-examples"},{"type":"function","title":"Pockets.reject/2","doc":"Akin to `Enum.reject/2`, this function will pare down the contents of the given\ntable deleting entries for which `fun` returns a truthy value.\nSimilar to using `Enum.filter/2` on maps, the `fun` receives a tuple representing\nthe key and the value stored at that location.\n\nThe result of a successful operation is an `:ok` tuple including the count of\nrows removed.\n\n>","ref":"Pockets.html#reject/2"},{"type":"function","title":"This Updates the Table In Place! {: .warning} - Pockets.reject/2","doc":">\n> This operation updates the table in place, so it has the potential to delete\n> every item in the table. Use it carefully!\n>\n> If a safer alternative is needed, use `Pockets.to_stream/1` to manipulate values\n> and feed the results into a new table.","ref":"Pockets.html#reject/2-this-updates-the-table-in-place-warning"},{"type":"function","title":"Examples - Pockets.reject/2","doc":"iex> Pockets.new(:ex)\n    iex> Pockets.merge(:ex, %{a: 12, b: 7, c: 22, d: 8})\n    iex> Pockets.reject(:ex, fn {_, v} -> v > 10 end)\n    {:ok, 2}\n    iex> Pockets.to_map(:ex)\n    %{b: 7, d: 8}","ref":"Pockets.html#reject/2-examples"},{"type":"function","title":"See Also - Pockets.reject/2","doc":"- `filter/2`","ref":"Pockets.html#reject/2-see-also"},{"type":"function","title":"Pockets.save_as/3","doc":"Both `:ets` and `:dets` files can be saved to disk. You can use this function to persist an in-memory `:ets`\nfile to disk for later use, or you can use it to make a copy of an existing `:dets` table.\n\nThe target file must not be in use by another table; if the target file exists this will return an error\nunless the `:overwrite?` option is set to true.\n\nOptions:\n\n- overwrite? default: `false`","ref":"Pockets.html#save_as/3"},{"type":"function","title":"Pockets.show_tables/1","doc":"Show all registered `Pockets` tables.","ref":"Pockets.html#show_tables/1"},{"type":"function","title":"Examples - Pockets.show_tables/1","doc":"iex> Pockets.show_tables()\n    [%Pockets.Table{alias: :my_cache, library: :ets, tid: :my_cache, type: :set}]","ref":"Pockets.html#show_tables/1-examples"},{"type":"function","title":"Pockets.size/1","doc":"Returns the size of the given table, measured by the number of entries.\nZero is returned if the table does not exist.","ref":"Pockets.html#size/1"},{"type":"function","title":"Pockets.to_list/1","doc":"Outputs the contents of the given table to a list.\nIf the table does not exist, an empty list is returned.\nAlthough this is useful for debugging purposes, for larger data sets consider using `to_stream/1` instead.","ref":"Pockets.html#to_list/1"},{"type":"function","title":"Pockets.to_map/1","doc":"Outputs the contents of the table to a map.\nIf the table does not exist, an empty map is returned.\nAlthough this is useful for debugging purposes, for larger data sets consider using `to_stream/1` instead.","ref":"Pockets.html#to_map/1"},{"type":"function","title":"Pockets.to_stream/1","doc":"Outputs the contents of the table to a stream for lazy evaluation.\nReturns an error tuple if the table does not exist.","ref":"Pockets.html#to_stream/1"},{"type":"function","title":"Pockets.truncate/1","doc":"Truncates the given table; this removes all entries from the table while leaving its options intact.","ref":"Pockets.html#truncate/1"},{"type":"function","title":"Examples - Pockets.truncate/1","doc":"iex> Pockets.put(:my_cache, :a, \"Apple\") |> Pockets.put(:b, \"boy\") |> Pockets.put(:c, \"Charlie\")\n    :my_cache\n    iex> Pockets.truncate(:my_cache)\n    :my_cache\n    iex> Pockets.to_map(:my_cache)\n    %{}","ref":"Pockets.html#truncate/1-examples"},{"type":"module","title":"Pockets.DetsInfo","doc":"A struct defining information about an Erlang `:dets` disk-based table,\nadapted from [:dets.info/1](https://erlang.org/doc/man/dets.html#info-1).\n\nThis struct is one of the possible values returned from `Pockets.info/1`.\n\nNote that `:dets` refers to a table's filename as a path that has been converted to an atom,\ne.g. `:\"/tmp/my_table.dets\"`","ref":"Pockets.DetsInfo.html"},{"type":"function","title":"Pockets.DetsInfo.new/1","doc":"","ref":"Pockets.DetsInfo.html#new/1"},{"type":"type","title":"Pockets.DetsInfo.t/0","doc":"","ref":"Pockets.DetsInfo.html#t:t/0"},{"type":"module","title":"Pockets.EtsInfo","doc":"A struct defining information about an Erlang `:ets` in-memory table,\nadapted from [:ets.info/1](https://erlang.org/doc/man/ets.html#info-1)\n\nThis struct is one of the possible values returned from `Pockets.info/1`.","ref":"Pockets.EtsInfo.html"},{"type":"function","title":"Pockets.EtsInfo.new/1","doc":"","ref":"Pockets.EtsInfo.html#new/1"},{"type":"type","title":"Pockets.EtsInfo.t/0","doc":"","ref":"Pockets.EtsInfo.html#t:t/0"},{"type":"module","title":"Pockets.Table","doc":"A simple struct that we store for each `Pockets` table so that we can nicely map what _you_\nuse to refer to your `Pockets` table and what the behind-the-scenes library uses to refer to the\ntable.\n\n- `alias`: what you (the developer) uses to refer to your `Pocket` tables.\n- `tid`: the table identifier: i.e. what the `library` uses to identify the table.\n- `library`: denotes either `:ets` or `:dets`\n- `type` : the type of storage. `:bag` | `:duplicate_bag` | `:set`","ref":"Pockets.Table.html"},{"type":"type","title":"Pockets.Table.t/0","doc":"","ref":"Pockets.Table.html#t:t/0"},{"type":"extras","title":"Pockets","doc":"# Pockets\n\n[![Module Version](https://img.shields.io/hexpm/v/pockets.svg)](https://hex.pm/packages/pockets)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/pockets/)\n[![Total Download](https://img.shields.io/hexpm/dt/pockets.svg)](https://hex.pm/packages/pockets)\n[![License](https://img.shields.io/hexpm/l/pockets.svg)](https://hex.pm/packages/pockets)\n[![Last Updated](https://img.shields.io/github/last-commit/fireproofsocks/pockets.svg)](https://github.com/fireproofsocks/pockets/commits/master)\n\nPockets is an Elixir wrapper around Erlang [ETS](https://erlang.org/doc/man/ets.html) and [DETS](https://erlang.org/doc/man/dets.html), Erlang's built-in solutions for memory- and disk-based term storage. Pockets aims to provide a simple and familiar interface for caching and persisting data by implementing many of the functions found in the built-in `Map` and `Keyword` modules. A pocket may hold data in memory or on disk.\n\nFor those needing more power or versatility than what `:ets` or `:dets` can offer, Elixir includes\n  [`:mnesia`](http://erlang.org/doc/man/mnesia.html).\n\nSecondly, the docs on [erlang.org](https://erlang.org/) are a bit rough to look at for Elixir developers, so\nthis package acts as a case study of the differences between the powerful built-in `:ets` and `:dets` libraries.\n\nIn case it was too subtle, \"Pockets\" is a name that includes \"ETS\" for mnemonic purposes.","ref":"readme.html"},{"type":"extras","title":"Installation - Pockets","doc":"Add `pockets` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:pockets, \"~> 1.5.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Pockets","doc":"A simple memory-based cache requires no special arguments:\n\n```elixir\niex> Pockets.new(:my_cache)\n{:ok, :my_cache}\niex> Pockets.put(:my_cache, :a, \"Apple\") |> Pockets.put(:b, \"boy\") |> Pockets.put(:c, \"Charlie\")\n:my_cache\niex> Pockets.get(:my_cache, :c)\n\"Charlie\"\n```\n\nUsing a disk-based cache is appropriate when you need your data to persist. Just supply a file path as the second argument to `Pockets.new/3`:\n\n```elixir\niex> Pockets.new(:on_disk, \"/tmp/cache.dets\")\n{:ok, :on_disk}\n```\n\nYou can easily populate your pocket with existing data:\n\n```elixir\niex> Pockets.new(:on_disk, \"/tmp/cache.dets\")\n{:ok, :on_disk}\niex> Pockets.merge(:on_disk, %{x: \"xylophone\", y: \"yellow\"})\n:on_disk\n```\n\nYou can easily inspect your data, e.g. using `Pockets.to_map/1`:\n\n```elixir\niex> Pockets.to_map(:on_disk)\n%{x: \"xylophone\", y: \"yellow\"}\n```\n\nSee the `Pockets` module documentation for more info!","ref":"readme.html#usage"},{"type":"extras","title":"Image Attribution - Pockets","doc":"\"pocket\" by Hilmi Hidayat from the [Noun Project](https://thenounproject.com/)","ref":"readme.html#image-attribution"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"v1.5.0 - Changelog","doc":"Bumps hex dependencies to latest versions.\nDocumentation cleanups","ref":"changelog.html#v1-5-0"},{"type":"extras","title":"v1.4.0 - Changelog","doc":"Changes the output format for `Pockets.filter/2` and `Pockets.reject/2`: success now\nreturns an `:ok` tuple with a count of the records removed.","ref":"changelog.html#v1-4-0"},{"type":"extras","title":"v1.3.0 - Changelog","doc":"Adds support for `Pockets.filter/2` and `Pockets.reject/2` for in-place editing of tables.\nBumps hex dependencies to latest versions.","ref":"changelog.html#v1-3-0"},{"type":"extras","title":"v1.2.0 - Changelog","doc":"Adds support for `Pockets.incr/4` function\nUpdates dependencies to latest available","ref":"changelog.html#v1-2-0"},{"type":"extras","title":"v1.1.0 - Changelog","doc":"Adds `Pockets.exists?/1` function.\nFix for   : Now returns :error when table does not exist\nVarious documentation cleanups.\nDowngrades Logger message from warn to debug when a table already exists.\nFixes some improper @specs; various dialyzer fixes\nDefines behavior for various functions when table does not exist\nVarious code linting","ref":"changelog.html#v1-1-0"},{"type":"extras","title":"v1.0.0 - Changelog","doc":"Tests! Support for `:bag` and `:duplicate_bag`!","ref":"changelog.html#v1-0-0"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"Initial release. Basic functionality present, but untested!","ref":"changelog.html#v0-1-0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}